#!/usr/bin/python3
# -*- coding: utf-8 -*-
 
import sys
import os
 
EJUDGE = bool(os.environ.get("EJUDGE", "0") == "1")
# Если установить переменную VERBOSE=0, то протокол выводиться не будет
# По умолчанию считается, что VERBOSE=1
VERBOSE = bool(os.environ.get("VERBOSE", "1") != "0")
YANDEX = False
 
if EJUDGE:
    OK = 0
    PE = 4
    WA = 5
    CF = 6
    AC = 8
else:
    OK = 0
    WA = 1
    PE = 2
    CF = 3
 
LOG = ""
 
def quit(status, log="", score=0):
    if EJUDGE and not VERBOSE and status != PE:  # Если планируется перетестирование, то нужно скрыть протокол
        log = "Полные протоколы проверки будут доступны после окончания олимпиады"
    if not log:  # Если задано значение параметра log, то выводится это значение, иначе выводится глобальная переменная LOG
        log = LOG
    sys.stderr.write(log)
    if EJUDGE:
        if status == WA or status == OK:
            sys.stdout.write(str(score) + "\n0\n" + str(AC) + "\n")
    elif YANDEX:
        if status == WA or status == OK:
            status = OK
            sys.stdout.write(score, log, sep=" \n")
        if status == PE:
            sys.stdout.write("Ошибка формата", log, sep="\n")
    else:  # Наверное, это полигон
        message_len = len(log.encode('utf-8'))
        if status == PE and message_len >= 127:
            sys.stderr.write("\n!!! Длина сообщения об ошибке слишком большая для ejudge !!!.\n")
            sys.stderr.write("Сократите длину сообщения на " + str(message_len - 127) + " байт.\n")
        sys.stdout.write("Score: " + str(score) + "\n")
    sys.exit(status)
 
fin = open(sys.argv[2], "r")
ans = fin.readline().strip().lower()
 
if (len(ans) == 0):
    quit(PE, "Ответ пустой")

ans = ans.replace("а", "a") # русская
ans = ans.replace("с", "c") # русская
ans = ans.replace("б", "b") # русская
ans = ans.replace("в", "b") # русская
ans = ans.replace(chr(8722), "-") # неправильный минус
 
for char in ans:
    if char not in " abc+-*()0123456789":
        quit(PE, "Ответ содержит недопустимый символ: ''" + char + "''" + "\n")
if "**" in ans:
    quit(PE, "В ответе не может использоваться ''**''" + "\n")
 
ALL_PASSED = True
 
ANSWERS = {
'2*c + 4*b + 8*a': 100,
'4*c + 2*b + 8*a': 80,
'2*c + 6*b + 6*a': 80,
'4*c + 4*b + 6*a': 60,
'2*c + 8*b + 4*a': 60,
'6*c + 2*b + 6*a': 50,
'4*c + 6*b + 4*a': 50,
'6*c + 4*b + 4*a': 40,
'4*c + 8*b + 2*a': 40,
'8*c + 2*b + 4*a': 30,
'6*c + 6*b + 2*a': 30,
'8*c + 4*b + 2*a': 20,
}
 
EPS = 1e-6
try:
    for a in range(1, 10):
        for b in range(a + 1, 10):
            for c in range(b + 1, 10):
                for sample in list(ANSWERS.keys()):
                    if abs(eval(ans) - eval(sample)) > EPS:
                        del ANSWERS[sample]
except ZeroDivisionError as E:
    quit(WA, "При вычислении выражения возникло деление на ноль\n", 0)
except Exception as E:
    quit(PE, "Некорректное арифметическое выражение.\n")
 
if len(ANSWERS) > 1:
    quit(CF, "Два подходящих варианта ответа в критериях оценивания\n" + str(ANSWERS), 0)
 
if len(ANSWERS) == 0:
    quit(WA, "Это неправильный ответ\n", 0)
 
for sample in ANSWERS:
    if ANSWERS[sample] == 100:
        quit(OK, "Это правильный ответ\n")
    else:
        quit(WA, "Ответ эквивалентен выражению " + sample + ".\nЭто неправильный ответ\n", ANSWERS[sample])
