#!/usr/bin/python3
# -*- coding: utf-8 -*-
 
import sys
import os
 
EJUDGE = bool(os.environ.get("EJUDGE", "0") == "1")
# Если установить переменную VERBOSE=0, то протокол выводиться не будет
# По умолчанию считается, что VERBOSE=1
VERBOSE = bool(os.environ.get("VERBOSE", "1") != "0")
YANDEX = False
 
if EJUDGE:
    OK = 0
    PE = 4
    WA = 5
    CF = 6
    AC = 8
else:
    OK = 0
    WA = 1
    PE = 2
    CF = 3
 
LOG = ""
 
def quit(status, log="", score=0):
    if EJUDGE and not VERBOSE and status != PE:  # Если планируется перетестирование, то нужно скрыть протокол
        log = "Полные протоколы проверки будут доступны после окончания олимпиады"
    if not log:  # Если задано значение параметра log, то выводится это значение, иначе выводится глобальная переменная LOG
        log = LOG
    sys.stderr.write(log)
    if EJUDGE:
        if status == WA or status == OK:
            sys.stdout.write(str(score) + "\n0\n" + str(AC) + "\n")
    elif YANDEX:
        if status == WA or status == OK:
            status = OK
            sys.stdout.write(score, log, sep=" \n")
        if status == PE:
            sys.stdout.write("Ошибка формата", log, sep="\n")
    else:  # Наверное, это полигон
        message_len = len(log.encode('utf-8'))
        if status == PE and message_len >= 127:
            sys.stderr.write("\n!!! Длина сообщения об ошибке слишком большая для ejudge !!!.\n")
            sys.stderr.write("Сократите длину сообщения на " + str(message_len - 127) + " байт.\n")
        sys.stdout.write("Score: " + str(score) + "\n")
    sys.exit(status)
 
fin = open(sys.argv[2], "r")
ans = fin.readlines()
i = 0
while i < len(ans):
    ans[i] = ans[i].strip().upper().replace(",", ".").replace(" ", "")
    if not ans[i]:
        ans.pop(i)
        continue
    i += 1
 
if len(ans) != 7:
    quit(PE, "В ответе должно быть ровно семь строк")
 
for i in range(7):
    if len(ans[i]) != 7:
        quit(PE, "Строка " + str(i + 1) + " неверной длины. В каждой строке должно быть 7 символов.")
    for c in ans[i]:
        if c not in ".AА":
            quit(PE, "Строка " + str(i + 1) + " содержит неверный символ. Допустимы только точки и буквы A")
 
for i in range(7):
    ans[i] = list(ans[i].replace("А", "A").replace("A", "X"))
 
if ans[0][0] != ".":
    quit(PE, "Левая верхняя клетка должна быть свободной (там должна стоять точка)")
 
 
def dfs(i, j):
    ans[i][j] = '*'
    for di, dj in [(1, 0), (0, 1), (-1, 0), (0, -1)]:
        ii = i + di
        jj = j + dj
        if ii < 0 or ii >= 7 or jj < 0 or jj >= 7:
            continue
        if ans[ii][jj] == '.':
            dfs(ii, jj)
        elif ans[ii][jj] == "X":
            ans[ii][jj] = "A"
 
 
dfs(0, 0)
 
for i in range(7):
    ans[i] = "".join(ans[i])
 
 
ans = "\n".join(ans).replace("*", ".")
 
count_ok = ans.count("A")
count_fail = ans.count("X")
 
SCORE = {28:100, 27: 70, 26: 40, 25: 20, 24: 10, 23:9, 22:8, 21:7, 20:6, 19:5}
 
def cars(n):
    if n % 10 == 1 and n // 10 != 1:
        return str(n) + " машина"
    elif 2 <= n % 10 <= 4 and n // 10 != 1:
        return str(n) + " машины"
    else:
        return str(n) + " машин"
 
if not count_fail:
    LOG += "В этом решении верно размещено " + cars(count_ok) + "\n"
    if count_ok == 28:
        LOG += "Это наилучшее решение"
        quit(OK, LOG, 100)
    else:
        LOG += "Это не самое лучшее решение"
        quit(WA, LOG, SCORE.get(count_ok, 0))
else:
    LOG += "Не все машины смогли выехать - не может выехать " + cars(count_fail) + "\n"
    LOG += "Может выехать " + cars(count_ok) + "\n"
    LOG += "Машины, которые не смогли выехать, отмечены знаком X\n\n"
    LOG += ans
    quit(WA, LOG, max(0, SCORE.get(count_ok, 0) - 20 * count_fail))
